==> jc-1.4.0.tar.gz: javax/swing/text/DocumentFilter.h <==
// public class javax.swing.text.DocumentFilter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5a7e5ea2211b5479 javax_swing_text_DocumentFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DocumentFilter_H_
#define _JC_javax_swing_text_DocumentFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object;

// Typedefs
typedef struct _jc_javax_swing_text_DocumentFilter$sub_refs	_jc_javax_swing_text_DocumentFilter$sub_refs;
typedef struct _jc_javax_swing_text_DocumentFilter$sub_nonrefs	_jc_javax_swing_text_DocumentFilter$sub_nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter$refs	_jc_javax_swing_text_DocumentFilter$refs;
typedef struct _jc_javax_swing_text_DocumentFilter$nonrefs	_jc_javax_swing_text_DocumentFilter$nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter$object	_jc_javax_swing_text_DocumentFilter$object;

typedef const struct _jc_javax_swing_text_DocumentFilter$vmethods	_jc_javax_swing_text_DocumentFilter$vmethods;
typedef const struct _jc_javax_swing_text_DocumentFilter$vtable	_jc_javax_swing_text_DocumentFilter$vtable;
typedef const struct _jc_javax_swing_text_DocumentFilter$vtype	_jc_javax_swing_text_DocumentFilter$vtype;

// Constructors
extern void _jc_javax_swing_text_DocumentFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *);

// Virtual methods
extern void _jc_javax_swing_text_DocumentFilter$method$insertString$6cfaaf9731a39cd0(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_javax_swing_text_DocumentFilter$method$remove$0407b6b504841621(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint);
extern void _jc_javax_swing_text_DocumentFilter$method$replace$b58846e9c250f2a8(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DocumentFilter$method_info$insertString$6cfaaf9731a39cd0;
extern _jc_method _jc_javax_swing_text_DocumentFilter$method_info$remove$0407b6b504841621;
extern _jc_method _jc_javax_swing_text_DocumentFilter$method_info$replace$b58846e9c250f2a8;

// Virtual methods structure
struct _jc_javax_swing_text_DocumentFilter$vmethods {
	void	(*insertString$6cfaaf9731a39cd0)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*remove$0407b6b504841621)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint);
	void	(*replace$b58846e9c250f2a8)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_swing_text_DocumentFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DocumentFilter$vmethods	javax_swing_text_DocumentFilter;
};

// Vtype
struct _jc_javax_swing_text_DocumentFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DocumentFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter$refs {
    _jc_javax_swing_text_DocumentFilter$sub_refs	javax_swing_text_DocumentFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DocumentFilter$sub_nonrefs	javax_swing_text_DocumentFilter;
};

// Object instance structure
struct _jc_javax_swing_text_DocumentFilter$object {
	_jc_javax_swing_text_DocumentFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DocumentFilter$vtype	*vtype;
	_jc_javax_swing_text_DocumentFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DocumentFilter$vtype _jc_javax_swing_text_DocumentFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DocumentFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DocumentFilter$class_object;

#endif	/* _JC_javax_swing_text_DocumentFilter_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/DocumentFilter.h <==
// public class javax.swing.text.DocumentFilter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5a7e5ea2211b5479 javax_swing_text_DocumentFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DocumentFilter_H_
#define _JC_javax_swing_text_DocumentFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object;

// Typedefs
typedef struct _jc_javax_swing_text_DocumentFilter$sub_refs	_jc_javax_swing_text_DocumentFilter$sub_refs;
typedef struct _jc_javax_swing_text_DocumentFilter$sub_nonrefs	_jc_javax_swing_text_DocumentFilter$sub_nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter$refs	_jc_javax_swing_text_DocumentFilter$refs;
typedef struct _jc_javax_swing_text_DocumentFilter$nonrefs	_jc_javax_swing_text_DocumentFilter$nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter$object	_jc_javax_swing_text_DocumentFilter$object;

typedef const struct _jc_javax_swing_text_DocumentFilter$vmethods	_jc_javax_swing_text_DocumentFilter$vmethods;
typedef const struct _jc_javax_swing_text_DocumentFilter$vtable	_jc_javax_swing_text_DocumentFilter$vtable;
typedef const struct _jc_javax_swing_text_DocumentFilter$vtype	_jc_javax_swing_text_DocumentFilter$vtype;

// Constructors
extern void _jc_javax_swing_text_DocumentFilter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_DocumentFilter$method$insertString$6cfaaf9731a39cd0(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DocumentFilter$method$remove$0407b6b504841621(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DocumentFilter$method$replace$b58846e9c250f2a8(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DocumentFilter$method_info$insertString$6cfaaf9731a39cd0;
extern _jc_method _jc_javax_swing_text_DocumentFilter$method_info$remove$0407b6b504841621;
extern _jc_method _jc_javax_swing_text_DocumentFilter$method_info$replace$b58846e9c250f2a8;

// Virtual methods structure
struct _jc_javax_swing_text_DocumentFilter$vmethods {
	void	(*insertString$6cfaaf9731a39cd0)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*remove$0407b6b504841621)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*replace$b58846e9c250f2a8)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter$object *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DocumentFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DocumentFilter$vmethods	javax_swing_text_DocumentFilter;
};

// Vtype
struct _jc_javax_swing_text_DocumentFilter$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DocumentFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter$refs {
    _jc_javax_swing_text_DocumentFilter$sub_refs	javax_swing_text_DocumentFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DocumentFilter$sub_nonrefs	javax_swing_text_DocumentFilter;
};

// Object instance structure
struct _jc_javax_swing_text_DocumentFilter$object {
	_jc_javax_swing_text_DocumentFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DocumentFilter$vtype	*vtype;
	_jc_javax_swing_text_DocumentFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DocumentFilter$vtype _jc_javax_swing_text_DocumentFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DocumentFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DocumentFilter$class_object;

#endif	/* _JC_javax_swing_text_DocumentFilter_H_ */
